@@ -85,7 +85,8 @@ module HeredocSupport
     while !scn.eos? do
       one_line = scn.scan_until(/(?:\n|\z)/)
       raise eof_error unless one_line
-      if md = one_line.match(endline_pattern)
+      md = one_line.match(endline_pattern)
+      if md
         leading      = md[1]
         has_margin   = md[2] == '|'
         remove_break = md[3] == '-'
