@@ -55,44 +55,35 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
      get(:uid)
   end
 
-  def comment
-     return localcomment if @resource.forcelocal?
-     get(:comment)
-  end
-
   def finduser(key, value)
     passwd_file = "/etc/passwd"
-    passwd_keys = [:account, :password, :uid, :gid, :gecos, :directory, :shell]
+    passwd_keys = ['account', 'password', 'uid', 'gid', 'gecos', 'directory', 'shell']
     index = passwd_keys.index(key)
     File.open(passwd_file) do |f|
       f.each_line do |line|
-        user = line.split(":")
-        if user[index] == value
-          return Hash[passwd_keys.zip(user)]
-        end
+         user = line.split(":")
+         if user[index] == value
+             f.close
+             return user
+         end
       end
     end
     false
   end
 
   def local_username
-    finduser(:uid, @resource.uid)
+    finduser('uid', @resource.uid)
   end
 
   def localuid
-    user = finduser(:account, resource[:name])
-    return user[:uid] if user
+    user = finduser('account', resource[:name])
+    return user[2] if user
     false
   end
 
-  def localcomment
-    user = finduser(:account, resource[:name])
-    user[:gecos]
-  end
-
   def shell=(value)
     check_valid_shell
-    set(:shell, value)
+    set("shell", value)
   end
 
   verify :gid, "GID must be an integer" do |value|
@@ -115,8 +106,8 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     # to ensure consistent behaviour of the useradd provider when
     # using both useradd and luseradd
     if (!@resource.allowdupe?) && @resource.forcelocal?
-       if @resource.should(:uid) && finduser(:uid, @resource.should(:uid).to_s)
-           raise(Puppet::Error, "UID #{@resource.should(:uid)} already exists, use allowdupe to force user creation")
+       if @resource.should(:uid) && finduser('uid', @resource.should(:uid).to_s)
+           raise(Puppet::Error, "UID #{@resource.should(:uid).to_s} already exists, use allowdupe to force user creation")
        end
     elsif @resource.allowdupe? && (!@resource.forcelocal?)
        return ["-o"]
@@ -125,7 +116,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
   end
 
   def check_valid_shell
-    unless File.exist?(@resource.should(:shell))
+    unless File.exists?(@resource.should(:shell))
       raise(Puppet::Error, "Shell #{@resource.should(:shell)} must exist")
     end
     unless File.executable?(@resource.should(:shell).to_s)
@@ -253,7 +244,8 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
   [:expiry, :password_min_age, :password_max_age, :password_warn_days, :password].each do |shadow_property|
     define_method(shadow_property) do
       if Puppet.features.libshadow?
-        if ent = Shadow::Passwd.getspnam(@canonical_name)
+        ent = Shadow::Passwd.getspnam(@canonical_name)
+        if ent
           method = self.class.option(shadow_property, :method)
           return unmunge(shadow_property, ent.send(method))
         end
